Method: Restspec::Schema::Types::TypeMethods#null

Defined in:
lib/restspec/schema/types/type_methods.rb

#null(options = {}) ⇒ Object

Creates a new NullType instance with the first argument passed as parameter to the NullType constructor.

Parameters:

  • options (Hash, Object) (defaults to: {})

    A hash of options or something to instantiate the type.



27
# File 'lib/restspec/schema/types/type_methods.rb', line 27

define_type_method :null, NullType