Creates a new NullType instance with the first argument passed as parameter to the NullType constructor.
Parameters:
A hash of options or something to instantiate the type.
27
# File 'lib/restspec/schema/types/type_methods.rb', line 27 define_type_method :null, NullType